@@ -14,7 +14,7 @@
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 """helper functions and classes to ease hg revision graph building
 
-Based on graphlog's algorithm, with insipration stolen to TortoiseHg
+Based on graphlog's algorithm, with inspiration stolen to TortoiseHg
 revision grapher.
 """
 
@@ -29,9 +29,9 @@ from mercurial.node import nullrev
 from mercurial import patch, util, match, error, hg
 
 import hgviewlib.hgpatches # force apply patches to mercurial
-from hgviewlib.hgpatches import mqsupport, phases
+from hgviewlib.hgpatches import mqsupport, phases, hiddenrevs
 
-from hgviewlib.util import tounicode, isbfile, first_known_precursors
+from hgviewlib.util import tounicode, isbfile, first_known_precursors, build_repo
 from hgviewlib.config import HgConfig
 
 DATE_FMT = '%F %R'
@@ -58,13 +58,15 @@ def diff(repo, ctx1, ctx2=None, files=None):
         matchfn = match.exact(repo.root, repo.getcwd(), files)
     # try/except for the sake of hg compatibility (API changes between
     # 1.0 and 1.1)
+    diffopts = patch.diffopts(repo.ui)
     try:
         out = StringIO()
-        patch.diff(repo, ctx2.node(), ctx1.node(), match=matchfn, fp=out)
+        patch.diff(repo, ctx2.node(), ctx1.node(), match=matchfn, fp=out,
+                   opts=diffopts)
         diffdata = out.getvalue()
     except:
         diffdata = '\n'.join(patch.diff(repo, ctx2.node(), ctx1.node(),
-                                        match=matchfn))
+                                        match=matchfn, opts=diffopts))
     # XXX how to deal diff encodings?
     try:
         diffdata = unicode(diffdata, "utf-8")
@@ -123,7 +125,7 @@ def ismerge(ctx):
     return False
 
 def _graph_iterator(repo, start_rev, stop_rev, reorder=False):
-    """Iter thought revisions from start_rev to stop_rev (included)
+    """Iter through revisions from start_rev to stop_rev (included)
     Handle Working directory as None.
     """
     # check parameters
@@ -186,7 +188,7 @@ def revision_grapher(repo, start_rev=None, stop_rev=0, branch=None, follow=False
             if not repo.mq.isapplied(patchname):
                 yield (patchname, 0, 0, [(0, 0 ,0, False)], [])
 
-    # No uncommited change
+    # No uncommitted change
     if start_rev is None and repo.status() == ([],)*7:
         start_rev = len(repo.changelog) -1
     assert start_rev is None or start_rev >= stop_rev
@@ -199,7 +201,7 @@ def revision_grapher(repo, start_rev=None, stop_rev=0, branch=None, follow=False
                     #            False for weak one (obsolete)
     rev_color = {}
     free_color = count(0)
-    excluded = () if show_hidden else repo.hiddenrevs
+    excluded = () if show_hidden else hiddenrevs(repo)
     closedbranches = [tag for tag, node in repo.branchtags().items()
                       if repo.lookup(node) not in repo.branchheads(tag, closed=False)]
     for curr_rev in _graph_iterator(repo, start_rev, stop_rev, not show_hidden and reorder):
@@ -351,7 +353,7 @@ class GraphNode(object):
 class Graph(object):
     """
     Graph object to ease hg repo navigation. The Graph object
-    instanciate a `revision_grapher` generator, and provide a `fill`
+    instantiate a `revision_grapher` generator, and provide a `fill`
     method to build the graph progressively.
     """
     #@timeit
@@ -389,7 +391,7 @@ class Graph(object):
             self.nodesdict[nrev] = gnode
             mcol.append(gnode.cols)
             if rev is not None and nrev <= rev:
-                rev = None # we reached rev, switching to nnode counter
+                rev = None # we reached rev, switching to nnodes counter
             if rev is None:
                 if nnodes is not None:
                     nnodes -= 1
@@ -529,7 +531,8 @@ class Graph(object):
                 else:
                     parentctx = self.repo[self._fileparent(fctx)]
                 data = diff(self.repo, ctx, parentctx, files=[filename])
-                data = data.split(os.linesep, 3)[-1]
+                # we assume that \n@@ marks the end of the diff header
+                data = ''.join(data.partition(os.linesep + '@@')[1:]).lstrip()
             elif flag == '':
                 data = ''
             else: # file renamed
@@ -585,7 +588,7 @@ class HgRepoListWalker(object):
 
     def setRepo(self, repo=None, branch='', fromhead=None, follow=False, closed=False):
         if repo is None:
-            repo = hg.repository(self.repo.ui, self.repo.root)
+            repo = build_repo(self.repo.ui, self.repo.root)
         self._hasmq = hasattr(self.repo, "mq")
         if not getattr(repo, '__hgview__', False) and self._hasmq:
             mqsupport.reposetup(repo.ui, repo)
@@ -720,16 +723,3 @@ class HgRepoListWalker(object):
 
     def notify_data_changed(self):
         pass
-
-if __name__ == "__main__":
-    # pylint: disable=C0103
-    import sys
-    from mercurial import ui, hg
-    u = ui.ui()
-    r = hg.repository(u, sys.argv[1])
-    if len(sys.argv) == 3:
-        rg = filelog_grapher(r, sys.argv[2])
-    else:
-        rg = revision_grapher(r)
-    g = Graph(r, rg)
-
