@@ -22,7 +22,8 @@ from operator import le, ge, lt, gt
 from mercurial import cmdutil, ui
 from mercurial.node import hex, short as short_hex, bin as short_bin
 
-from mercurial.error import RepoError, ParseError, LookupError, RepoLookupError
+from mercurial.error import (RepoError, ParseError, LookupError,
+                             RepoLookupError, Abort)
 
 from PyQt4 import QtCore, QtGui
 Qt = QtCore.Qt
@@ -80,7 +81,7 @@ class GotoQuery(QtCore.QThread):
         revset = None
         try:
             revset = revrange(self.model.repo, [self.revexp.encode('utf-8')])
-        except (RepoError, ParseError, LookupError, RepoLookupError), err:
+        except (RepoError, ParseError, LookupError, RepoLookupError, Abort), err:
             self.rows = None
             self.emit(SIGNAL('failed_revset'), err)
             return
@@ -232,11 +233,11 @@ class GotoQuickBar(QuickBar):
         w.activateWindow()
 
     def auto_search(self, revexp):
-        # Do not automatically search for revision nimber.
+        # Do not automatically search for revision number.
         # The problem is that the auto search system will
         # query for lower revision number: users may type the revision
         # number by hand which induce that the first numeric char will be
-        # querined alone.
+        # queried alone.
         # But the first found revision is automatically selected, so to much
         # revision tree will be loaded.
         if revexp.isdigit():
@@ -245,8 +246,8 @@ class GotoQuickBar(QuickBar):
             self._actions['prev'].setEnabled(True)
             self.show_message(
                 'Hit [Enter] because '
-                'revision number is not automaically queried '
-                'for optimmization purpose.')
+                'revision number is not automatically queried '
+                'for optimization purpose.')
             self._standby_revexp = revexp
             return
         self.search(revexp)
@@ -258,7 +259,7 @@ class GotoQuickBar(QuickBar):
             if self.entry.status == 'failed':
                 self.show_message("Invalid revset expression.")
             else:
-                self.show_message("Quering, please wait (or edit to cancel).")
+                self.show_message("Querying, please wait (or edit to cancel).")
             return
         if self._standby_revexp is not None:
             self.search(self._standby_revexp, threaded=False)
@@ -285,7 +286,7 @@ class GotoQuickBar(QuickBar):
             self.emit(SIGNAL('new_set'), None)
             self.emit(SIGNAL('goto_next_from'), (self.row_before,))
             return
-        self.show_message("Quering ... (edit the entry to cancel)")
+        self.show_message("Querying ... (edit the entry to cancel)")
         self._actions['next'].setEnabled(False)
         self._actions['prev'].setEnabled(False)
         self.entry.status = 'query'
@@ -391,7 +392,7 @@ class HgRepoView(QtGui.QTableView):
             ActDef(name="back",
                    desc=self.tr("Previous visited"),
                    icon='back',
-                   tip=self.tr("Barward to the previous visited changeset"),
+                   tip=self.tr("Backward to the previous visited changeset"),
                    keys=[QtGui.QKeySequence(QtGui.QKeySequence.Back)],
                    cb=self.back),
             ActDef(name="forward",
@@ -451,7 +452,7 @@ class HgRepoView(QtGui.QTableView):
         self._actions['unfilter'].setEnabled(rev is not None)
 
     def copy_cs_to_clipboard(self):
-        """ Copy changeset metada into the window manager clipboard."""
+        """ Copy changeset metadata into the window manager clipboard."""
         repo = self.model().repo
         ctx = repo[self.current_rev]
         u = ui.ui(repo.ui)
@@ -492,7 +493,7 @@ class HgRepoView(QtGui.QTableView):
         self._rev_pos = -1
         self._in_history = False # flag set when we are "in" the
         # history. It is required cause we cannot known, in
-        # "revision_selected", if we are crating a new branch in the
+        # "revision_selected", if we are creating a new branch in the
         # history navigation or if we are navigating the history
 
     def setModel(self, model):
@@ -503,6 +504,8 @@ class HgRepoView(QtGui.QTableView):
                 self.revisionSelected)
         tags = model.repo.tags().keys()
         self.goto_toolbar.compl_model.add_to_string_list(*tags)
+        revaliases = [item[0] for item in model.repo.ui.configitems("revsetalias")]
+        self.goto_toolbar.compl_model.add_to_string_list(*revaliases)
         col = list(model._columns).index('Log')
         self.horizontalHeader().setResizeMode(col, QtGui.QHeaderView.Stretch)
 
