@@ -20,7 +20,7 @@ from mercurial.error import RepoError
 
 
 from hgviewlib.application import HgRepoViewer as _HgRepoViewer
-from hgviewlib.util import tounicode, find_repository, rootpath
+from hgviewlib.util import tounicode, find_repository, rootpath, build_repo
 from hgviewlib.hggraph import diff as revdiff
 from hgviewlib.decorators import timeit
 from hgviewlib.config import HgConfig
@@ -32,6 +32,7 @@ from hgviewlib.qt4.hgmanifestdialog import ManifestViewer
 from hgviewlib.qt4.hgdialogmixin import HgDialogMixin
 from hgviewlib.qt4.quickbar import FindInGraphlogQuickBar
 from hgviewlib.qt4.helpviewer import HgviewHelpViewer
+from hgviewlib.hgpatches import hiddenrevs
 
 from mercurial.error import RepoError
 
@@ -84,6 +85,16 @@ class HgRepoViewer(QtGui.QMainWindow, HgDialogMixin, _HgRepoViewer):
             self.setupBranchCombo()
             self.setupModels(fromhead)
  
+        if self.cfg.getFileDescriptionView() == 'asfile':
+            fileselcallback = self.displaySelectedFile
+        else:
+            fileselcallback = self.textview_status.displayFile
+        connect(self.tableView_filelist, SIGNAL('fileSelected'),
+                fileselcallback)
+
+        connect(self.textview_status, SIGNAL('revForDiffChanged'),
+                self.textview_header.setDiffRevision)
+
         if fromhead:
             self.startrev_entry.setText(str(fromhead))
         self.setupRevisionTable()
@@ -354,15 +365,6 @@ class HgRepoViewer(QtGui.QMainWindow, HgDialogMixin, _HgRepoViewer):
         self.textview_status.setModel(self.repomodel)
         self.find_toolbar.setModel(self.repomodel)
 
-        if self.cfg.getFileDescriptionView() == 'asfile':
-            fileselcallback = self.displaySelectedFile
-        else:
-            fileselcallback = self.textview_status.displayFile
-        connect(self.tableView_filelist, SIGNAL('fileSelected'),
-                fileselcallback)
-
-        connect(self.textview_status, SIGNAL('revForDiffChanged'),
-                self.textview_header.setDiffRevision)
 
     def displaySelectedFile(self, filename=None, rev=None):
         if filename == '':
@@ -465,7 +467,7 @@ class HgRepoViewer(QtGui.QMainWindow, HgDialogMixin, _HgRepoViewer):
         if self.repomodel.show_hidden:
             self.textview_header.excluded = ()
         else:
-            self.textview_header.excluded = self.repo.hiddenrevs
+            self.textview_header.excluded = hiddenrevs(self.repo)
         self.textview_header.displayRevision(ctx)
         self.filelistmodel.setSelectedRev(ctx)
         if len(self.filelistmodel):
@@ -515,7 +517,7 @@ class HgRepoViewer(QtGui.QMainWindow, HgDialogMixin, _HgRepoViewer):
                 raise RepoError("There is no Mercurial repository here (.hg not found)!")
             else:
                 return
-        repo = hg.repository(ui.ui(), repopath)
+        repo = build_repo(ui.ui(), repopath)
         return repo
 
     def open_repository(self):
@@ -531,7 +533,7 @@ class HgRepoViewer(QtGui.QMainWindow, HgDialogMixin, _HgRepoViewer):
         """Reload the repository"""
         self._reload_rev = self.tableView_revisions.current_rev
         self._reload_file = self.tableView_filelist.currentFile()
-        self.repo = hg.repository(self.repo.ui, self.repo.root)
+        self.repo = build_repo(self.repo.ui, self.repo.root)
         self._finish_load()
 
     def _finish_load(self):
@@ -544,9 +546,9 @@ class HgRepoViewer(QtGui.QMainWindow, HgDialogMixin, _HgRepoViewer):
         """Starts the process of filling the HgModel"""
         branch = str(self.branch_comboBox.currentText())
         startrev = kw.get('rev', None)
-        # XXX workaround: self.sender() may provoque a core dump if
+        # XXX workaround: self.sender() may provoke a core dump if
         # this method is called directly (not via a connected signal);
-        # the 'sender' keyword is a way to discrimimne that the method
+        # the 'sender' keyword is a way to detect that the method
         # has been called directly (thus caller MUST set this kw arg)
         sender = kw.get('sender') or self.sender()
         follow = kw.get('follow', False)
