@@ -10,7 +10,7 @@ Several helper functions
 """
 import os
 import string
-from mercurial import ui
+from mercurial import ui, hg
 
 from hgviewlib.hgpatches.scmutil import match
 from hgviewlib.hgpatches import precursorsmarkers, successorsmarkers
@@ -109,7 +109,7 @@ ESC_CAR_TABLE = string.maketrans(''.join(CONTROL_CHARS),
 ESC_UCAR_TABLE = unicode(ESC_CAR_TABLE, 'latin1')
 
 def xml_escape(data):
-    """escapes XML forbidden characters in attributes and PCDATA"""
+    """escapes XML forbidden characters in attributes and CDATA"""
     if isinstance(data, unicode):
         data = data.translate(ESC_UCAR_TABLE)
     else:
@@ -129,12 +129,17 @@ def format_desc(desc, width):
 
 def first_known_precursors(ctx, excluded=()):
     obsstore = getattr(ctx._repo, 'obsstore', None)
+    startnode = ctx.node()
     nm = ctx._repo.changelog.nodemap
     if obsstore is not None:
-        markers = precursorsmarkers(obsstore, ctx.node())
+        markers = precursorsmarkers(obsstore, startnode)
         # consider all precursors
         candidates = set(mark[0] for mark in markers)
         seen = set(candidates)
+        if startnode in candidates:
+            candidates.remove(startnode)
+        else:
+            seen.add(startnode)
         while candidates:
             current = candidates.pop()
             # is this changeset in the displayed set ?
@@ -149,14 +154,19 @@ def first_known_precursors(ctx, excluded=()):
 
 def first_known_successors(ctx, excluded=()):
     obsstore = getattr(ctx._repo, 'obsstore', None)
+    startnode = ctx.node()
     nm = ctx._repo.changelog.nodemap
     if obsstore is not None:
-        markers = successorsmarkers(obsstore, ctx.node())
+        markers = successorsmarkers(obsstore, startnode)
         # consider all precursors
         candidates = set()
         for mark in markers:
             candidates.update(mark[1])
         seen = set(candidates)
+        if startnode in candidates:
+            candidates.remove(startnode)
+        else:
+            seen.add(startnode)
         while candidates:
             current = candidates.pop()
             # is this changeset in the displayed set ?
@@ -165,6 +175,14 @@ def first_known_successors(ctx, excluded=()):
                 yield ctx._repo[crev]
             else:
                 for mark in successorsmarkers(obsstore, current):
-                    if mark[0] not in seen:
-                        candidates.add(mark[0])
-                        seen.add(mark[0])
+                    for succ in mark[1]:
+                        if succ not in seen:
+                            candidates.add(succ)
+                            seen.add(succ)
+
+def build_repo(ui, path):
+    """build a repo like hg.repository
+
+    But ensure it is not filtered whatever the version used"""
+    repo = hg.repository(ui, path)
+    return getattr(repo, 'unfiltered', lambda: repo)()
